@@ -1,6 +1,5 @@
 (TeX-add-style-hook "addingToolkit"
- (function
-  (lambda ()
+ (lambda ()
     (LaTeX-add-environments
      "RArgs")
     (LaTeX-add-labels
@@ -13,8 +12,6 @@
      '("RCode" 1)
      "VERSION")
     (TeX-run-style-hooks
-     "fancyhdr"
-     "jvfloatstyle"
      "fancyhdr"
      "fancyvrb"
      "color"
@@ -30,5 +27,5 @@
      "latex2e"
      "art12"
      "article"
-     "12pt"))))
+     "12pt")))
 
